@@ -71,7 +71,7 @@ import cx_Oracle                                    # type: ignore
 from ae.db_core import DbBase, SystemBase           # type: ignore  # SystemBase is an indirect import from ae.sys_core
 
 
-__version__ = '0.2.5'
+__version__ = '0.2.6'
 
 
 class OraDb(DbBase):
@@ -158,8 +158,8 @@ class OraDb(DbBase):
         :param value:   the input value passed into the reference parameter of the called stored procedure.
         :return:        a handle to the reference variable.
 
-        the following code snippet shows how to use this method together with :meth:`~.get_value` for
-        to retrieve the returned value of a reference parameter::
+        the following code snippet shows how to use this method together with :meth:`~.get_value` to retrieve the
+        returned value of a reference parameter::
 
             ora_db = OraDb(...)
             *ref_var* = ora_db.prepare_ref_param("input_value")
